from .. import IconBase


class IconTriangleAlert(IconBase):
    class_name = "lucide lucide-triangle-alert"
    svg_data = {
    "attrs": {
        "width": "24",
        "height": "24",
        "viewBox": "0 0 24 24",
        "fill": "none",
        "stroke": "currentColor",
        "stroke_width": "2",
        "stroke_linecap": "round",
        "stroke_linejoin": "round"
    },
    "items": [
        {
            "path": {
                "d": "m21.73 18-8-14a2 2 0 0 0-3.48 0l-8 14A2 2 0 0 0 4 21h16a2 2 0 0 0 1.73-3"
            }
        },
        {
            "path": {
                "d": "M12 9v4"
            }
        },
        {
            "path": {
                "d": "M12 17h.01"
            }
        }
    ]
}



from .. import IconBase


class IconLampDesk(IconBase):
    class_name = "lucide lucide-lamp-desk"
    svg_data = {
    "attrs": {
        "width": "24",
        "height": "24",
        "viewBox": "0 0 24 24",
        "fill": "none",
        "stroke": "currentColor",
        "stroke_width": "2",
        "stroke_linecap": "round",
        "stroke_linejoin": "round"
    },
    "items": [
        {
            "path": {
                "d": "m14 5-3 3 2 7 8-8-7-2Z"
            }
        },
        {
            "path": {
                "d": "m14 5-3 3-3-3 3-3 3 3Z"
            }
        },
        {
            "path": {
                "d": "M9.5 6.5 4 12l3 6"
            }
        },
        {
            "path": {
                "d": "M3 22v-2c0-1.1.9-2 2-2h4a2 2 0 0 1 2 2v2H3Z"
            }
        }
    ]
}



from .. import IconBase


class IconPrinter(IconBase):
    class_name = "lucide lucide-printer"
    svg_data = {
    "attrs": {
        "width": "24",
        "height": "24",
        "viewBox": "0 0 24 24",
        "fill": "none",
        "stroke": "currentColor",
        "stroke_width": "2",
        "stroke_linecap": "round",
        "stroke_linejoin": "round"
    },
    "items": [
        {
            "polyline": {
                "points": "6 9 6 2 18 2 18 9"
            }
        },
        {
            "path": {
                "d": "M6 18H4a2 2 0 0 1-2-2v-5a2 2 0 0 1 2-2h16a2 2 0 0 1 2 2v5a2 2 0 0 1-2 2h-2"
            }
        },
        {
            "rect": {
                "width": "12",
                "height": "8",
                "x": "6",
                "y": "14"
            }
        }
    ]
}



from .. import IconBase


class IconMails(IconBase):
    class_name = "lucide lucide-mails"
    svg_data = {
    "attrs": {
        "width": "24",
        "height": "24",
        "viewBox": "0 0 24 24",
        "fill": "none",
        "stroke": "currentColor",
        "stroke_width": "2",
        "stroke_linecap": "round",
        "stroke_linejoin": "round"
    },
    "items": [
        {
            "rect": {
                "width": "16",
                "height": "13",
                "x": "6",
                "y": "4",
                "rx": "2"
            }
        },
        {
            "path": {
                "d": "m22 7-7.1 3.78c-.57.3-1.23.3-1.8 0L6 7"
            }
        },
        {
            "path": {
                "d": "M2 8v11c0 1.1.9 2 2 2h14"
            }
        }
    ]
}



from .. import IconBase


class IconMessagesSquare(IconBase):
    class_name = "lucide lucide-messages-square"
    svg_data = {
    "attrs": {
        "width": "24",
        "height": "24",
        "viewBox": "0 0 24 24",
        "fill": "none",
        "stroke": "currentColor",
        "stroke_width": "2",
        "stroke_linecap": "round",
        "stroke_linejoin": "round"
    },
    "items": [
        {
            "path": {
                "d": "M14 9a2 2 0 0 1-2 2H6l-4 4V4c0-1.1.9-2 2-2h8a2 2 0 0 1 2 2z"
            }
        },
        {
            "path": {
                "d": "M18 9h2a2 2 0 0 1 2 2v11l-4-4h-6a2 2 0 0 1-2-2v-1"
            }
        }
    ]
}



from .. import IconBase


class IconCalendarX2(IconBase):
    class_name = "lucide lucide-calendar-x-2"
    svg_data = {
    "attrs": {
        "width": "24",
        "height": "24",
        "viewBox": "0 0 24 24",
        "fill": "none",
        "stroke": "currentColor",
        "stroke_width": "2",
        "stroke_linecap": "round",
        "stroke_linejoin": "round"
    },
    "items": [
        {
            "path": {
                "d": "M8 2v4"
            }
        },
        {
            "path": {
                "d": "M16 2v4"
            }
        },
        {
            "path": {
                "d": "M21 13V6a2 2 0 0 0-2-2H5a2 2 0 0 0-2 2v14a2 2 0 0 0 2 2h8"
            }
        },
        {
            "path": {
                "d": "M3 10h18"
            }
        },
        {
            "path": {
                "d": "m17 22 5-5"
            }
        },
        {
            "path": {
                "d": "m17 17 5 5"
            }
        }
    ]
}



from .. import IconBase


class IconPictureInPicture(IconBase):
    class_name = "lucide lucide-picture-in-picture"
    svg_data = {
    "attrs": {
        "width": "24",
        "height": "24",
        "viewBox": "0 0 24 24",
        "fill": "none",
        "stroke": "currentColor",
        "stroke_width": "2",
        "stroke_linecap": "round",
        "stroke_linejoin": "round"
    },
    "items": [
        {
            "path": {
                "d": "M8 4.5v5H3m-1-6 6 6m13 0v-3c0-1.16-.84-2-2-2h-7m-9 9v2c0 1.05.95 2 2 2h3"
            }
        },
        {
            "rect": {
                "width": "10",
                "height": "7",
                "x": "12",
                "y": "13.5",
                "ry": "2"
            }
        }
    ]
}



from .. import IconBase


class IconMonitorSmartphone(IconBase):
    class_name = "lucide lucide-monitor-smartphone"
    svg_data = {
    "attrs": {
        "width": "24",
        "height": "24",
        "viewBox": "0 0 24 24",
        "fill": "none",
        "stroke": "currentColor",
        "stroke_width": "2",
        "stroke_linecap": "round",
        "stroke_linejoin": "round"
    },
    "items": [
        {
            "path": {
                "d": "M18 8V6a2 2 0 0 0-2-2H4a2 2 0 0 0-2 2v7a2 2 0 0 0 2 2h8"
            }
        },
        {
            "path": {
                "d": "M10 19v-3.96 3.15"
            }
        },
        {
            "path": {
                "d": "M7 19h5"
            }
        },
        {
            "rect": {
                "width": "6",
                "height": "10",
                "x": "16",
                "y": "12",
                "rx": "2"
            }
        }
    ]
}



from .. import IconBase


class IconBatteryCharging(IconBase):
    class_name = "lucide lucide-battery-charging"
    svg_data = {
    "attrs": {
        "width": "24",
        "height": "24",
        "viewBox": "0 0 24 24",
        "fill": "none",
        "stroke": "currentColor",
        "stroke_width": "2",
        "stroke_linecap": "round",
        "stroke_linejoin": "round"
    },
    "items": [
        {
            "path": {
                "d": "M15 7h1a2 2 0 0 1 2 2v6a2 2 0 0 1-2 2h-2"
            }
        },
        {
            "path": {
                "d": "M6 7H4a2 2 0 0 0-2 2v6a2 2 0 0 0 2 2h1"
            }
        },
        {
            "path": {
                "d": "m11 7-3 5h4l-3 5"
            }
        },
        {
            "line": {
                "x1": "22",
                "x2": "22",
                "y1": "11",
                "y2": "13"
            }
        }
    ]
}



from .. import IconBase


class IconMouseOff(IconBase):
    class_name = "lucide lucide-mouse-off"
    svg_data = {
    "attrs": {
        "width": "24",
        "height": "24",
        "viewBox": "0 0 24 24",
        "fill": "none",
        "stroke": "currentColor",
        "stroke_width": "2",
        "stroke_linecap": "round",
        "stroke_linejoin": "round"
    },
    "items": [
        {
            "path": {
                "d": "M12 6v.343"
            }
        },
        {
            "path": {
                "d": "M18.218 18.218A7 7 0 0 1 5 15V9a7 7 0 0 1 .782-3.218"
            }
        },
        {
            "path": {
                "d": "M19 13.343V9A7 7 0 0 0 8.56 2.902"
            }
        },
        {
            "path": {
                "d": "M22 22 2 2"
            }
        }
    ]
}



from .. import IconBase


class IconMonitorDot(IconBase):
    class_name = "lucide lucide-monitor-dot"
    svg_data = {
    "attrs": {
        "width": "24",
        "height": "24",
        "viewBox": "0 0 24 24",
        "fill": "none",
        "stroke": "currentColor",
        "stroke_width": "2",
        "stroke_linecap": "round",
        "stroke_linejoin": "round"
    },
    "items": [
        {
            "circle": {
                "cx": "19",
                "cy": "6",
                "r": "3"
            }
        },
        {
            "path": {
                "d": "M22 12v3a2 2 0 0 1-2 2H4a2 2 0 0 1-2-2V5a2 2 0 0 1 2-2h9"
            }
        },
        {
            "path": {
                "d": "M12 17v4"
            }
        },
        {
            "path": {
                "d": "M8 21h8"
            }
        }
    ]
}



from .. import IconBase


class IconUsersRound(IconBase):
    class_name = "lucide lucide-users-round"
    svg_data = {
    "attrs": {
        "width": "24",
        "height": "24",
        "viewBox": "0 0 24 24",
        "fill": "none",
        "stroke": "currentColor",
        "stroke_width": "2",
        "stroke_linecap": "round",
        "stroke_linejoin": "round"
    },
    "items": [
        {
            "path": {
                "d": "M18 21a8 8 0 0 0-16 0"
            }
        },
        {
            "circle": {
                "cx": "10",
                "cy": "8",
                "r": "5"
            }
        },
        {
            "path": {
                "d": "M22 20c0-3.37-2-6.5-4-8a5 5 0 0 0-.45-8.3"
            }
        }
    ]
}



from .. import IconBase


class IconBraces(IconBase):
    class_name = "lucide lucide-braces"
    svg_data = {
    "attrs": {
        "width": "24",
        "height": "24",
        "viewBox": "0 0 24 24",
        "fill": "none",
        "stroke": "currentColor",
        "stroke_width": "2",
        "stroke_linecap": "round",
        "stroke_linejoin": "round"
    },
    "items": [
        {
            "path": {
                "d": "M8 3H7a2 2 0 0 0-2 2v5a2 2 0 0 1-2 2 2 2 0 0 1 2 2v5c0 1.1.9 2 2 2h1"
            }
        },
        {
            "path": {
                "d": "M16 21h1a2 2 0 0 0 2-2v-5c0-1.1.9-2 2-2a2 2 0 0 1-2-2V5a2 2 0 0 0-2-2h-1"
            }
        }
    ]
}



from .. import IconBase


class IconFolderMinus(IconBase):
    class_name = "lucide lucide-folder-minus"
    svg_data = {
    "attrs": {
        "width": "24",
        "height": "24",
        "viewBox": "0 0 24 24",
        "fill": "none",
        "stroke": "currentColor",
        "stroke_width": "2",
        "stroke_linecap": "round",
        "stroke_linejoin": "round"
    },
    "items": [
        {
            "path": {
                "d": "M9 13h6"
            }
        },
        {
            "path": {
                "d": "M20 20a2 2 0 0 0 2-2V8a2 2 0 0 0-2-2h-7.9a2 2 0 0 1-1.69-.9L9.6 3.9A2 2 0 0 0 7.93 3H4a2 2 0 0 0-2 2v13a2 2 0 0 0 2 2Z"
            }
        }
    ]
}



from .. import IconBase


class IconAlignCenterHorizontal(IconBase):
    class_name = "lucide lucide-align-center-horizontal"
    svg_data = {
    "attrs": {
        "width": "24",
        "height": "24",
        "viewBox": "0 0 24 24",
        "fill": "none",
        "stroke": "currentColor",
        "stroke_width": "2",
        "stroke_linecap": "round",
        "stroke_linejoin": "round"
    },
    "items": [
        {
            "path": {
                "d": "M2 12h20"
            }
        },
        {
            "path": {
                "d": "M10 16v4a2 2 0 0 1-2 2H6a2 2 0 0 1-2-2v-4"
            }
        },
        {
            "path": {
                "d": "M10 8V4a2 2 0 0 0-2-2H6a2 2 0 0 0-2 2v4"
            }
        },
        {
            "path": {
                "d": "M20 16v1a2 2 0 0 1-2 2h-2a2 2 0 0 1-2-2v-1"
            }
        },
        {
            "path": {
                "d": "M14 8V7c0-1.1.9-2 2-2h2a2 2 0 0 1 2 2v1"
            }
        }
    ]
}



from .. import IconBase


class IconFileMusic(IconBase):
    class_name = "lucide lucide-file-music"
    svg_data = {
    "attrs": {
        "width": "24",
        "height": "24",
        "viewBox": "0 0 24 24",
        "fill": "none",
        "stroke": "currentColor",
        "stroke_width": "2",
        "stroke_linecap": "round",
        "stroke_linejoin": "round"
    },
    "items": [
        {
            "circle": {
                "cx": "14",
                "cy": "16",
                "r": "2"
            }
        },
        {
            "circle": {
                "cx": "6",
                "cy": "18",
                "r": "2"
            }
        },
        {
            "path": {
                "d": "M4 12.4V4a2 2 0 0 1 2-2h8.5L20 7.5V20a2 2 0 0 1-2 2h-7.5"
            }
        },
        {
            "path": {
                "d": "M8 18v-7.7L16 9v7"
            }
        }
    ]
}



from .. import IconBase


class IconHeading2(IconBase):
    class_name = "lucide lucide-heading-2"
    svg_data = {
    "attrs": {
        "width": "24",
        "height": "24",
        "viewBox": "0 0 24 24",
        "fill": "none",
        "stroke": "currentColor",
        "stroke_width": "2",
        "stroke_linecap": "round",
        "stroke_linejoin": "round"
    },
    "items": [
        {
            "path": {
                "d": "M4 12h8"
            }
        },
        {
            "path": {
                "d": "M4 18V6"
            }
        },
        {
            "path": {
                "d": "M12 18V6"
            }
        },
        {
            "path": {
                "d": "M21 18h-4c0-4 4-3 4-6 0-1.5-2-2.5-4-1"
            }
        }
    ]
}



from .. import IconBase


class IconCloudy(IconBase):
    class_name = "lucide lucide-cloudy"
    svg_data = {
    "attrs": {
        "width": "24",
        "height": "24",
        "viewBox": "0 0 24 24",
        "fill": "none",
        "stroke": "currentColor",
        "stroke_width": "2",
        "stroke_linecap": "round",
        "stroke_linejoin": "round"
    },
    "items": [
        {
            "path": {
                "d": "M17.5 21H9a7 7 0 1 1 6.71-9h1.79a4.5 4.5 0 1 1 0 9Z"
            }
        },
        {
            "path": {
                "d": "M22 10a3 3 0 0 0-3-3h-2.207a5.502 5.502 0 0 0-10.702.5"
            }
        }
    ]
}



from .. import IconBase


class IconStar(IconBase):
    class_name = "lucide lucide-star"
    svg_data = {
    "attrs": {
        "width": "24",
        "height": "24",
        "viewBox": "0 0 24 24",
        "fill": "none",
        "stroke": "currentColor",
        "stroke_width": "2",
        "stroke_linecap": "round",
        "stroke_linejoin": "round"
    },
    "items": [
        {
            "polygon": {
                "points": "12 2 15.09 8.26 22 9.27 17 14.14 18.18 21.02 12 17.77 5.82 21.02 7 14.14 2 9.27 8.91 8.26 12 2"
            }
        }
    ]
}



from .. import IconBase


class IconPaperclip(IconBase):
    class_name = "lucide lucide-paperclip"
    svg_data = {
    "attrs": {
        "width": "24",
        "height": "24",
        "viewBox": "0 0 24 24",
        "fill": "none",
        "stroke": "currentColor",
        "stroke_width": "2",
        "stroke_linecap": "round",
        "stroke_linejoin": "round"
    },
    "items": [
        {
            "path": {
                "d": "m21.44 11.05-9.19 9.19a6 6 0 0 1-8.49-8.49l8.57-8.57A4 4 0 1 1 18 8.84l-8.59 8.57a2 2 0 0 1-2.83-2.83l8.49-8.48"
            }
        }
    ]
}



from .. import IconBase


class IconSlice(IconBase):
    class_name = "lucide lucide-slice"
    svg_data = {
    "attrs": {
        "width": "24",
        "height": "24",
        "viewBox": "0 0 24 24",
        "fill": "none",
        "stroke": "currentColor",
        "stroke_width": "2",
        "stroke_linecap": "round",
        "stroke_linejoin": "round"
    },
    "items": [
        {
            "path": {
                "d": "m8 14-6 6h9v-3"
            }
        },
        {
            "path": {
                "d": "M18.37 3.63 8 14l3 3L21.37 6.63a2.12 2.12 0 1 0-3-3Z"
            }
        }
    ]
}



from .. import IconBase


class IconPopsicle(IconBase):
    class_name = "lucide lucide-popsicle"
    svg_data = {
    "attrs": {
        "width": "24",
        "height": "24",
        "viewBox": "0 0 24 24",
        "fill": "none",
        "stroke": "currentColor",
        "stroke_width": "2",
        "stroke_linecap": "round",
        "stroke_linejoin": "round"
    },
    "items": [
        {
            "path": {
                "d": "M18.6 14.4c.8-.8.8-2 0-2.8l-8.1-8.1a4.95 4.95 0 1 0-7.1 7.1l8.1 8.1c.9.7 2.1.7 2.9-.1Z"
            }
        },
        {
            "path": {
                "d": "m22 22-5.5-5.5"
            }
        }
    ]
}



from .. import IconBase


class IconMonitorSpeaker(IconBase):
    class_name = "lucide lucide-monitor-speaker"
    svg_data = {
    "attrs": {
        "width": "24",
        "height": "24",
        "viewBox": "0 0 24 24",
        "fill": "none",
        "stroke": "currentColor",
        "stroke_width": "2",
        "stroke_linecap": "round",
        "stroke_linejoin": "round"
    },
    "items": [
        {
            "path": {
                "d": "M5.5 20H8"
            }
        },
        {
            "path": {
                "d": "M17 9h.01"
            }
        },
        {
            "rect": {
                "width": "10",
                "height": "16",
                "x": "12",
                "y": "4",
                "rx": "2"
            }
        },
        {
            "path": {
                "d": "M8 6H4a2 2 0 0 0-2 2v6a2 2 0 0 0 2 2h4"
            }
        },
        {
            "circle": {
                "cx": "17",
                "cy": "15",
                "r": "1"
            }
        }
    ]
}



from .. import IconBase


class IconBotMessageSquare(IconBase):
    class_name = "lucide lucide-bot-message-square"
    svg_data = {
    "attrs": {
        "width": "24",
        "height": "24",
        "viewBox": "0 0 24 24",
        "fill": "none",
        "stroke": "currentColor",
        "stroke_width": "2",
        "stroke_linecap": "round",
        "stroke_linejoin": "round"
    },
    "items": [
        {
            "path": {
                "d": "M12 6V2H8"
            }
        },
        {
            "path": {
                "d": "m8 18-4 4V8a2 2 0 0 1 2-2h12a2 2 0 0 1 2 2v8a2 2 0 0 1-2 2Z"
            }
        },
        {
            "path": {
                "d": "M2 12h2"
            }
        },
        {
            "path": {
                "d": "M9 11v2"
            }
        },
        {
            "path": {
                "d": "M15 11v2"
            }
        },
        {
            "path": {
                "d": "M20 12h2"
            }
        }
    ]
}



from .. import IconBase


class IconPaintbrush2(IconBase):
    class_name = "lucide lucide-paintbrush-2"
    svg_data = {
    "attrs": {
        "width": "24",
        "height": "24",
        "viewBox": "0 0 24 24",
        "fill": "none",
        "stroke": "currentColor",
        "stroke_width": "2",
        "stroke_linecap": "round",
        "stroke_linejoin": "round"
    },
    "items": [
        {
            "path": {
                "d": "M14 19.9V16h3a2 2 0 0 0 2-2v-2H5v2c0 1.1.9 2 2 2h3v3.9a2 2 0 1 0 4 0Z"
            }
        },
        {
            "path": {
                "d": "M6 12V2h12v10"
            }
        },
        {
            "path": {
                "d": "M14 2v4"
            }
        },
        {
            "path": {
                "d": "M10 2v2"
            }
        }
    ]
}



from .. import IconBase


class IconOctagonX(IconBase):
    class_name = "lucide lucide-octagon-x"
    svg_data = {
    "attrs": {
        "width": "24",
        "height": "24",
        "viewBox": "0 0 24 24",
        "fill": "none",
        "stroke": "currentColor",
        "stroke_width": "2",
        "stroke_linecap": "round",
        "stroke_linejoin": "round"
    },
    "items": [
        {
            "polygon": {
                "points": "7.86 2 16.14 2 22 7.86 22 16.14 16.14 22 7.86 22 2 16.14 2 7.86 7.86 2"
            }
        },
        {
            "path": {
                "d": "m15 9-6 6"
            }
        },
        {
            "path": {
                "d": "m9 9 6 6"
            }
        }
    ]
}



from .. import IconBase


class IconWrapText(IconBase):
    class_name = "lucide lucide-wrap-text"
    svg_data = {
    "attrs": {
        "width": "24",
        "height": "24",
        "viewBox": "0 0 24 24",
        "fill": "none",
        "stroke": "currentColor",
        "stroke_width": "2",
        "stroke_linecap": "round",
        "stroke_linejoin": "round"
    },
    "items": [
        {
            "line": {
                "x1": "3",
                "x2": "21",
                "y1": "6",
                "y2": "6"
            }
        },
        {
            "path": {
                "d": "M3 12h15a3 3 0 1 1 0 6h-4"
            }
        },
        {
            "polyline": {
                "points": "16 16 14 18 16 20"
            }
        },
        {
            "line": {
                "x1": "3",
                "x2": "10",
                "y1": "18",
                "y2": "18"
            }
        }
    ]
}



from .. import IconBase


class IconMessageCircleOff(IconBase):
    class_name = "lucide lucide-message-circle-off"
    svg_data = {
    "attrs": {
        "width": "24",
        "height": "24",
        "viewBox": "0 0 24 24",
        "fill": "none",
        "stroke": "currentColor",
        "stroke_width": "2",
        "stroke_linecap": "round",
        "stroke_linejoin": "round"
    },
    "items": [
        {
            "path": {
                "d": "M20.5 14.9A9 9 0 0 0 9.1 3.5"
            }
        },
        {
            "path": {
                "d": "m2 2 20 20"
            }
        },
        {
            "path": {
                "d": "M5.6 5.6C3 8.3 2.2 12.5 4 16l-2 6 6-2c3.4 1.8 7.6 1.1 10.3-1.7"
            }
        }
    ]
}



from .. import IconBase


class IconFolderInput(IconBase):
    class_name = "lucide lucide-folder-input"
    svg_data = {
    "attrs": {
        "width": "24",
        "height": "24",
        "viewBox": "0 0 24 24",
        "fill": "none",
        "stroke": "currentColor",
        "stroke_width": "2",
        "stroke_linecap": "round",
        "stroke_linejoin": "round"
    },
    "items": [
        {
            "path": {
                "d": "M2 9V5a2 2 0 0 1 2-2h3.9a2 2 0 0 1 1.69.9l.81 1.2a2 2 0 0 0 1.67.9H20a2 2 0 0 1 2 2v10a2 2 0 0 1-2 2H4a2 2 0 0 1-2-2v-1"
            }
        },
        {
            "path": {
                "d": "M2 13h10"
            }
        },
        {
            "path": {
                "d": "m9 16 3-3-3-3"
            }
        }
    ]
}



from .. import IconBase


class IconFolderPen(IconBase):
    class_name = "lucide lucide-folder-pen"
    svg_data = {
    "attrs": {
        "width": "24",
        "height": "24",
        "viewBox": "0 0 24 24",
        "fill": "none",
        "stroke": "currentColor",
        "stroke_width": "2",
        "stroke_linecap": "round",
        "stroke_linejoin": "round"
    },
    "items": [
        {
            "path": {
                "d": "M8.4 10.6a2 2 0 0 1 3 3L6 19l-4 1 1-4Z"
            }
        },
        {
            "path": {
                "d": "M2 11.5V5a2 2 0 0 1 2-2h3.9c.7 0 1.3.3 1.7.9l.8 1.2c.4.6 1 .9 1.7.9H20a2 2 0 0 1 2 2v10a2 2 0 0 1-2 2h-9.5"
            }
        }
    ]
}



from .. import IconBase


class IconMessageCircleX(IconBase):
    class_name = "lucide lucide-message-circle-x"
    svg_data = {
    "attrs": {
        "width": "24",
        "height": "24",
        "viewBox": "0 0 24 24",
        "fill": "none",
        "stroke": "currentColor",
        "stroke_width": "2",
        "stroke_linecap": "round",
        "stroke_linejoin": "round"
    },
    "items": [
        {
            "path": {
                "d": "M7.9 20A9 9 0 1 0 4 16.1L2 22Z"
            }
        },
        {
            "path": {
                "d": "m15 9-6 6"
            }
        },
        {
            "path": {
                "d": "m9 9 6 6"
            }
        }
    ]
}



from .. import IconBase


class IconNewspaper(IconBase):
    class_name = "lucide lucide-newspaper"
    svg_data = {
    "attrs": {
        "width": "24",
        "height": "24",
        "viewBox": "0 0 24 24",
        "fill": "none",
        "stroke": "currentColor",
        "stroke_width": "2",
        "stroke_linecap": "round",
        "stroke_linejoin": "round"
    },
    "items": [
        {
            "path": {
                "d": "M4 22h16a2 2 0 0 0 2-2V4a2 2 0 0 0-2-2H8a2 2 0 0 0-2 2v16a2 2 0 0 1-2 2Zm0 0a2 2 0 0 1-2-2v-9c0-1.1.9-2 2-2h2"
            }
        },
        {
            "path": {
                "d": "M18 14h-8"
            }
        },
        {
            "path": {
                "d": "M15 18h-5"
            }
        },
        {
            "path": {
                "d": "M10 6h8v4h-8V6Z"
            }
        }
    ]
}



from .. import IconBase


class IconWind(IconBase):
    class_name = "lucide lucide-wind"
    svg_data = {
    "attrs": {
        "width": "24",
        "height": "24",
        "viewBox": "0 0 24 24",
        "fill": "none",
        "stroke": "currentColor",
        "stroke_width": "2",
        "stroke_linecap": "round",
        "stroke_linejoin": "round"
    },
    "items": [
        {
            "path": {
                "d": "M17.7 7.7a2.5 2.5 0 1 1 1.8 4.3H2"
            }
        },
        {
            "path": {
                "d": "M9.6 4.6A2 2 0 1 1 11 8H2"
            }
        },
        {
            "path": {
                "d": "M12.6 19.4A2 2 0 1 0 14 16H2"
            }
        }
    ]
}



from .. import IconBase


class IconCaptionsOff(IconBase):
    class_name = "lucide lucide-captions-off"
    svg_data = {
    "attrs": {
        "width": "24",
        "height": "24",
        "viewBox": "0 0 24 24",
        "fill": "none",
        "stroke": "currentColor",
        "stroke_width": "2",
        "stroke_linecap": "round",
        "stroke_linejoin": "round"
    },
    "items": [
        {
            "path": {
                "d": "M10.5 5H19a2 2 0 0 1 2 2v8.5"
            }
        },
        {
            "path": {
                "d": "M17 11h-.5"
            }
        },
        {
            "path": {
                "d": "M19 19H5a2 2 0 0 1-2-2V7a2 2 0 0 1 2-2"
            }
        },
        {
            "path": {
                "d": "m2 2 20 20"
            }
        },
        {
            "path": {
                "d": "M7 11h4"
            }
        },
        {
            "path": {
                "d": "M7 15h2.5"
            }
        }
    ]
}



from .. import IconBase


class IconFileBadge(IconBase):
    class_name = "lucide lucide-file-badge"
    svg_data = {
    "attrs": {
        "width": "24",
        "height": "24",
        "viewBox": "0 0 24 24",
        "fill": "none",
        "stroke": "currentColor",
        "stroke_width": "2",
        "stroke_linecap": "round",
        "stroke_linejoin": "round"
    },
    "items": [
        {
            "path": {
                "d": "M12 22h6a2 2 0 0 0 2-2V7l-5-5H6a2 2 0 0 0-2 2v3"
            }
        },
        {
            "path": {
                "d": "M14 2v4a2 2 0 0 0 2 2h4"
            }
        },
        {
            "path": {
                "d": "M5 17a3 3 0 1 0 0-6 3 3 0 0 0 0 6Z"
            }
        },
        {
            "path": {
                "d": "M7 16.5 8 22l-3-1-3 1 1-5.5"
            }
        }
    ]
}



from .. import IconBase


class IconFolderClock(IconBase):
    class_name = "lucide lucide-folder-clock"
    svg_data = {
    "attrs": {
        "width": "24",
        "height": "24",
        "viewBox": "0 0 24 24",
        "fill": "none",
        "stroke": "currentColor",
        "stroke_width": "2",
        "stroke_linecap": "round",
        "stroke_linejoin": "round"
    },
    "items": [
        {
            "circle": {
                "cx": "16",
                "cy": "16",
                "r": "6"
            }
        },
        {
            "path": {
                "d": "M7 20H4a2 2 0 0 1-2-2V5a2 2 0 0 1 2-2h3.9a2 2 0 0 1 1.69.9l.81 1.2a2 2 0 0 0 1.67.9H20a2 2 0 0 1 2 2"
            }
        },
        {
            "path": {
                "d": "M16 14v2l1 1"
            }
        }
    ]
}



from .. import IconBase


class IconInfinity(IconBase):
    class_name = "lucide lucide-infinity"
    svg_data = {
    "attrs": {
        "width": "24",
        "height": "24",
        "viewBox": "0 0 24 24",
        "fill": "none",
        "stroke": "currentColor",
        "stroke_width": "2",
        "stroke_linecap": "round",
        "stroke_linejoin": "round"
    },
    "items": [
        {
            "path": {
                "d": "M12 12c-2-2.67-4-4-6-4a4 4 0 1 0 0 8c2 0 4-1.33 6-4Zm0 0c2 2.67 4 4 6 4a4 4 0 0 0 0-8c-2 0-4 1.33-6 4Z"
            }
        }
    ]
}



from .. import IconBase


class IconRepeat2(IconBase):
    class_name = "lucide lucide-repeat-2"
    svg_data = {
    "attrs": {
        "width": "24",
        "height": "24",
        "viewBox": "0 0 24 24",
        "fill": "none",
        "stroke": "currentColor",
        "stroke_width": "2",
        "stroke_linecap": "round",
        "stroke_linejoin": "round"
    },
    "items": [
        {
            "path": {
                "d": "m2 9 3-3 3 3"
            }
        },
        {
            "path": {
                "d": "M13 18H7a2 2 0 0 1-2-2V6"
            }
        },
        {
            "path": {
                "d": "m22 15-3 3-3-3"
            }
        },
        {
            "path": {
                "d": "M11 6h6a2 2 0 0 1 2 2v10"
            }
        }
    ]
}



from .. import IconBase


class IconSatellite(IconBase):
    class_name = "lucide lucide-satellite"
    svg_data = {
    "attrs": {
        "width": "24",
        "height": "24",
        "viewBox": "0 0 24 24",
        "fill": "none",
        "stroke": "currentColor",
        "stroke_width": "2",
        "stroke_linecap": "round",
        "stroke_linejoin": "round"
    },
    "items": [
        {
            "path": {
                "d": "M13 7 9 3 5 7l4 4"
            }
        },
        {
            "path": {
                "d": "m17 11 4 4-4 4-4-4"
            }
        },
        {
            "path": {
                "d": "m8 12 4 4 6-6-4-4Z"
            }
        },
        {
            "path": {
                "d": "m16 8 3-3"
            }
        },
        {
            "path": {
                "d": "M9 21a6 6 0 0 0-6-6"
            }
        }
    ]
}



from .. import IconBase


class IconFlameKindling(IconBase):
    class_name = "lucide lucide-flame-kindling"
    svg_data = {
    "attrs": {
        "width": "24",
        "height": "24",
        "viewBox": "0 0 24 24",
        "fill": "none",
        "stroke": "currentColor",
        "stroke_width": "2",
        "stroke_linecap": "round",
        "stroke_linejoin": "round"
    },
    "items": [
        {
            "path": {
                "d": "M12 2c1 3 2.5 3.5 3.5 4.5A5 5 0 0 1 17 10a5 5 0 1 1-10 0c0-.3 0-.6.1-.9a2 2 0 1 0 3.3-2C8 4.5 11 2 12 2Z"
            }
        },
        {
            "path": {
                "d": "m5 22 14-4"
            }
        },
        {
            "path": {
                "d": "m5 18 14 4"
            }
        }
    ]
}



from .. import IconBase


class IconBellMinus(IconBase):
    class_name = "lucide lucide-bell-minus"
    svg_data = {
    "attrs": {
        "width": "24",
        "height": "24",
        "viewBox": "0 0 24 24",
        "fill": "none",
        "stroke": "currentColor",
        "stroke_width": "2",
        "stroke_linecap": "round",
        "stroke_linejoin": "round"
    },
    "items": [
        {
            "path": {
                "d": "M18.4 12c.8 3.8 2.6 5 2.6 5H3s3-2 3-9c0-3.3 2.7-6 6-6 1.8 0 3.4.8 4.5 2"
            }
        },
        {
            "path": {
                "d": "M10.3 21a1.94 1.94 0 0 0 3.4 0"
            }
        },
        {
            "path": {
                "d": "M15 8h6"
            }
        }
    ]
}



from .. import IconBase


class IconKeyRound(IconBase):
    class_name = "lucide lucide-key-round"
    svg_data = {
    "attrs": {
        "width": "24",
        "height": "24",
        "viewBox": "0 0 24 24",
        "fill": "none",
        "stroke": "currentColor",
        "stroke_width": "2",
        "stroke_linecap": "round",
        "stroke_linejoin": "round"
    },
    "items": [
        {
            "path": {
                "d": "M2 18v3c0 .6.4 1 1 1h4v-3h3v-3h2l1.4-1.4a6.5 6.5 0 1 0-4-4Z"
            }
        },
        {
            "circle": {
                "cx": "16.5",
                "cy": "7.5",
                "r": ".5",
                "fill": "currentColor"
            }
        }
    ]
}



from .. import IconBase


class IconTicketSlash(IconBase):
    class_name = "lucide lucide-ticket-slash"
    svg_data = {
    "attrs": {
        "width": "24",
        "height": "24",
        "viewBox": "0 0 24 24",
        "fill": "none",
        "stroke": "currentColor",
        "stroke_width": "2",
        "stroke_linecap": "round",
        "stroke_linejoin": "round"
    },
    "items": [
        {
            "path": {
                "d": "M2 9a3 3 0 0 1 0 6v2a2 2 0 0 0 2 2h16a2 2 0 0 0 2-2v-2a3 3 0 0 1 0-6V7a2 2 0 0 0-2-2H4a2 2 0 0 0-2 2Z"
            }
        },
        {
            "path": {
                "d": "m9.5 14.5 5-5"
            }
        }
    ]
}



from .. import IconBase


class IconThermometerSnowflake(IconBase):
    class_name = "lucide lucide-thermometer-snowflake"
    svg_data = {
    "attrs": {
        "width": "24",
        "height": "24",
        "viewBox": "0 0 24 24",
        "fill": "none",
        "stroke": "currentColor",
        "stroke_width": "2",
        "stroke_linecap": "round",
        "stroke_linejoin": "round"
    },
    "items": [
        {
            "path": {
                "d": "M2 12h10"
            }
        },
        {
            "path": {
                "d": "M9 4v16"
            }
        },
        {
            "path": {
                "d": "m3 9 3 3-3 3"
            }
        },
        {
            "path": {
                "d": "M12 6 9 9 6 6"
            }
        },
        {
            "path": {
                "d": "m6 18 3-3 1.5 1.5"
            }
        },
        {
            "path": {
                "d": "M20 4v10.54a4 4 0 1 1-4 0V4a2 2 0 0 1 4 0Z"
            }
        }
    ]
}



from .. import IconBase


class IconScreenShareOff(IconBase):
    class_name = "lucide lucide-screen-share-off"
    svg_data = {
    "attrs": {
        "width": "24",
        "height": "24",
        "viewBox": "0 0 24 24",
        "fill": "none",
        "stroke": "currentColor",
        "stroke_width": "2",
        "stroke_linecap": "round",
        "stroke_linejoin": "round"
    },
    "items": [
        {
            "path": {
                "d": "M13 3H4a2 2 0 0 0-2 2v10a2 2 0 0 0 2 2h16a2 2 0 0 0 2-2v-3"
            }
        },
        {
            "path": {
                "d": "M8 21h8"
            }
        },
        {
            "path": {
                "d": "M12 17v4"
            }
        },
        {
            "path": {
                "d": "m22 3-5 5"
            }
        },
        {
            "path": {
                "d": "m17 3 5 5"
            }
        }
    ]
}



from .. import IconBase


class IconWallet(IconBase):
    class_name = "lucide lucide-wallet"
    svg_data = {
    "attrs": {
        "width": "24",
        "height": "24",
        "viewBox": "0 0 24 24",
        "fill": "none",
        "stroke": "currentColor",
        "stroke_width": "2",
        "stroke_linecap": "round",
        "stroke_linejoin": "round"
    },
    "items": [
        {
            "path": {
                "d": "M19 7V4a1 1 0 0 0-1-1H5a2 2 0 0 0 0 4h15a1 1 0 0 1 1 1v4h-3a2 2 0 0 0 0 4h3a1 1 0 0 0 1-1v-2a1 1 0 0 0-1-1"
            }
        },
        {
            "path": {
                "d": "M3 5v14a2 2 0 0 0 2 2h15a1 1 0 0 0 1-1v-4"
            }
        }
    ]
}



from .. import IconBase


class IconBringToFront(IconBase):
    class_name = "lucide lucide-bring-to-front"
    svg_data = {
    "attrs": {
        "width": "24",
        "height": "24",
        "viewBox": "0 0 24 24",
        "fill": "none",
        "stroke": "currentColor",
        "stroke_width": "2",
        "stroke_linecap": "round",
        "stroke_linejoin": "round"
    },
    "items": [
        {
            "rect": {
                "x": "8",
                "y": "8",
                "width": "8",
                "height": "8",
                "rx": "2"
            }
        },
        {
            "path": {
                "d": "M4 10a2 2 0 0 1-2-2V4a2 2 0 0 1 2-2h4a2 2 0 0 1 2 2"
            }
        },
        {
            "path": {
                "d": "M14 20a2 2 0 0 0 2 2h4a2 2 0 0 0 2-2v-4a2 2 0 0 0-2-2"
            }
        }
    ]
}



from .. import IconBase


class IconMerge(IconBase):
    class_name = "lucide lucide-merge"
    svg_data = {
    "attrs": {
        "width": "24",
        "height": "24",
        "viewBox": "0 0 24 24",
        "fill": "none",
        "stroke": "currentColor",
        "stroke_width": "2",
        "stroke_linecap": "round",
        "stroke_linejoin": "round"
    },
    "items": [
        {
            "path": {
                "d": "m8 6 4-4 4 4"
            }
        },
        {
            "path": {
                "d": "M12 2v10.3a4 4 0 0 1-1.172 2.872L4 22"
            }
        },
        {
            "path": {
                "d": "m20 22-5-5"
            }
        }
    ]
}



from .. import IconBase


class IconMessageSquareQuote(IconBase):
    class_name = "lucide lucide-message-square-quote"
    svg_data = {
    "attrs": {
        "width": "24",
        "height": "24",
        "viewBox": "0 0 24 24",
        "fill": "none",
        "stroke": "currentColor",
        "stroke_width": "2",
        "stroke_linecap": "round",
        "stroke_linejoin": "round"
    },
    "items": [
        {
            "path": {
                "d": "M21 15a2 2 0 0 1-2 2H7l-4 4V5a2 2 0 0 1 2-2h14a2 2 0 0 1 2 2z"
            }
        },
        {
            "path": {
                "d": "M8 12a2 2 0 0 0 2-2V8H8"
            }
        },
        {
            "path": {
                "d": "M14 12a2 2 0 0 0 2-2V8h-2"
            }
        }
    ]
}



from .. import IconBase


class IconCakeSlice(IconBase):
    class_name = "lucide lucide-cake-slice"
    svg_data = {
    "attrs": {
        "width": "24",
        "height": "24",
        "viewBox": "0 0 24 24",
        "fill": "none",
        "stroke": "currentColor",
        "stroke_width": "2",
        "stroke_linecap": "round",
        "stroke_linejoin": "round"
    },
    "items": [
        {
            "circle": {
                "cx": "9",
                "cy": "7",
                "r": "2"
            }
        },
        {
            "path": {
                "d": "M7.2 7.9 3 11v9c0 .6.4 1 1 1h16c.6 0 1-.4 1-1v-9c0-2-3-6-7-8l-3.6 2.6"
            }
        },
        {
            "path": {
                "d": "M16 13H3"
            }
        },
        {
            "path": {
                "d": "M16 17H3"
            }
        }
    ]
}



from .. import IconBase


class IconCloudMoon(IconBase):
    class_name = "lucide lucide-cloud-moon"
    svg_data = {
    "attrs": {
        "width": "24",
        "height": "24",
        "viewBox": "0 0 24 24",
        "fill": "none",
        "stroke": "currentColor",
        "stroke_width": "2",
        "stroke_linecap": "round",
        "stroke_linejoin": "round"
    },
    "items": [
        {
            "path": {
                "d": "M13 16a3 3 0 1 1 0 6H7a5 5 0 1 1 4.9-6Z"
            }
        },
        {
            "path": {
                "d": "M10.1 9A6 6 0 0 1 16 4a4.24 4.24 0 0 0 6 6 6 6 0 0 1-3 5.197"
            }
        }
    ]
}



from .. import IconBase


class IconTreeDeciduous(IconBase):
    class_name = "lucide lucide-tree-deciduous"
    svg_data = {
    "attrs": {
        "width": "24",
        "height": "24",
        "viewBox": "0 0 24 24",
        "fill": "none",
        "stroke": "currentColor",
        "stroke_width": "2",
        "stroke_linecap": "round",
        "stroke_linejoin": "round"
    },
    "items": [
        {
            "path": {
                "d": "M8 19a4 4 0 0 1-2.24-7.32A3.5 3.5 0 0 1 9 6.03V6a3 3 0 1 1 6 0v.04a3.5 3.5 0 0 1 3.24 5.65A4 4 0 0 1 16 19Z"
            }
        },
        {
            "path": {
                "d": "M12 19v3"
            }
        }
    ]
}



from .. import IconBase


class IconFolderDot(IconBase):
    class_name = "lucide lucide-folder-dot"
    svg_data = {
    "attrs": {
        "width": "24",
        "height": "24",
        "viewBox": "0 0 24 24",
        "fill": "none",
        "stroke": "currentColor",
        "stroke_width": "2",
        "stroke_linecap": "round",
        "stroke_linejoin": "round"
    },
    "items": [
        {
            "path": {
                "d": "M4 20h16a2 2 0 0 0 2-2V8a2 2 0 0 0-2-2h-7.93a2 2 0 0 1-1.66-.9l-.82-1.2A2 2 0 0 0 7.93 3H4a2 2 0 0 0-2 2v13c0 1.1.9 2 2 2Z"
            }
        },
        {
            "circle": {
                "cx": "12",
                "cy": "13",
                "r": "1"
            }
        }
    ]
}



from .. import IconBase


class IconGitGraph(IconBase):
    class_name = "lucide lucide-git-graph"
    svg_data = {
    "attrs": {
        "width": "24",
        "height": "24",
        "viewBox": "0 0 24 24",
        "fill": "none",
        "stroke": "currentColor",
        "stroke_width": "2",
        "stroke_linecap": "round",
        "stroke_linejoin": "round"
    },
    "items": [
        {
            "circle": {
                "cx": "5",
                "cy": "6",
                "r": "3"
            }
        },
        {
            "path": {
                "d": "M5 9v6"
            }
        },
        {
            "circle": {
                "cx": "5",
                "cy": "18",
                "r": "3"
            }
        },
        {
            "path": {
                "d": "M12 3v18"
            }
        },
        {
            "circle": {
                "cx": "19",
                "cy": "6",
                "r": "3"
            }
        },
        {
            "path": {
                "d": "M16 15.7A9 9 0 0 0 19 9"
            }
        }
    ]
}



from .. import IconBase


class IconTerminal(IconBase):
    class_name = "lucide lucide-terminal"
    svg_data = {
    "attrs": {
        "width": "24",
        "height": "24",
        "viewBox": "0 0 24 24",
        "fill": "none",
        "stroke": "currentColor",
        "stroke_width": "2",
        "stroke_linecap": "round",
        "stroke_linejoin": "round"
    },
    "items": [
        {
            "polyline": {
                "points": "4 17 10 11 4 5"
            }
        },
        {
            "line": {
                "x1": "12",
                "x2": "20",
                "y1": "19",
                "y2": "19"
            }
        }
    ]
}



from .. import IconBase


class IconTrash(IconBase):
    class_name = "lucide lucide-trash"
    svg_data = {
    "attrs": {
        "width": "24",
        "height": "24",
        "viewBox": "0 0 24 24",
        "fill": "none",
        "stroke": "currentColor",
        "stroke_width": "2",
        "stroke_linecap": "round",
        "stroke_linejoin": "round"
    },
    "items": [
        {
            "path": {
                "d": "M3 6h18"
            }
        },
        {
            "path": {
                "d": "M19 6v14c0 1-1 2-2 2H7c-1 0-2-1-2-2V6"
            }
        },
        {
            "path": {
                "d": "M8 6V4c0-1 1-2 2-2h4c1 0 2 1 2 2v2"
            }
        }
    ]
}



from .. import IconBase


class IconLampWallUp(IconBase):
    class_name = "lucide lucide-lamp-wall-up"
    svg_data = {
    "attrs": {
        "width": "24",
        "height": "24",
        "viewBox": "0 0 24 24",
        "fill": "none",
        "stroke": "currentColor",
        "stroke_width": "2",
        "stroke_linecap": "round",
        "stroke_linejoin": "round"
    },
    "items": [
        {
            "path": {
                "d": "M11 4h6l3 7H8l3-7Z"
            }
        },
        {
            "path": {
                "d": "M14 11v5a2 2 0 0 1-2 2H8"
            }
        },
        {
            "path": {
                "d": "M4 15h2a2 2 0 0 1 2 2v2a2 2 0 0 1-2 2H4v-6Z"
            }
        }
    ]
}



from .. import IconBase


class IconBookLock(IconBase):
    class_name = "lucide lucide-book-lock"
    svg_data = {
    "attrs": {
        "width": "24",
        "height": "24",
        "viewBox": "0 0 24 24",
        "fill": "none",
        "stroke": "currentColor",
        "stroke_width": "2",
        "stroke_linecap": "round",
        "stroke_linejoin": "round"
    },
    "items": [
        {
            "path": {
                "d": "M4 19.5v-15A2.5 2.5 0 0 1 6.5 2H10"
            }
        },
        {
            "path": {
                "d": "M20 15v7H6.5a2.5 2.5 0 0 1 0-5H20"
            }
        },
        {
            "rect": {
                "width": "8",
                "height": "5",
                "x": "12",
                "y": "6",
                "rx": "1"
            }
        },
        {
            "path": {
                "d": "M18 6V4a2 2 0 1 0-4 0v2"
            }
        }
    ]
}



from .. import IconBase


class IconAmpersand(IconBase):
    class_name = "lucide lucide-ampersand"
    svg_data = {
    "attrs": {
        "width": "24",
        "height": "24",
        "viewBox": "0 0 24 24",
        "fill": "none",
        "stroke": "currentColor",
        "stroke_width": "2",
        "stroke_linecap": "round",
        "stroke_linejoin": "round"
    },
    "items": [
        {
            "path": {
                "d": "M17.5 12c0 4.4-3.6 8-8 8A4.5 4.5 0 0 1 5 15.5c0-6 8-4 8-8.5a3 3 0 1 0-6 0c0 3 2.5 8.5 12 13"
            }
        },
        {
            "path": {
                "d": "M16 12h3"
            }
        }
    ]
}



from .. import IconBase


class IconSquareParkingOff(IconBase):
    class_name = "lucide lucide-square-parking-off"
    svg_data = {
    "attrs": {
        "width": "24",
        "height": "24",
        "viewBox": "0 0 24 24",
        "fill": "none",
        "stroke": "currentColor",
        "stroke_width": "2",
        "stroke_linecap": "round",
        "stroke_linejoin": "round"
    },
    "items": [
        {
            "path": {
                "d": "M3.6 3.6A2 2 0 0 1 5 3h14a2 2 0 0 1 2 2v14a2 2 0 0 1-.59 1.41"
            }
        },
        {
            "path": {
                "d": "M3 8.7V19a2 2 0 0 0 2 2h10.3"
            }
        },
        {
            "path": {
                "d": "m2 2 20 20"
            }
        },
        {
            "path": {
                "d": "M13 13a3 3 0 1 0 0-6H9v2"
            }
        },
        {
            "path": {
                "d": "M9 17v-2.3"
            }
        }
    ]
}



from .. import IconBase


class IconALargeSmall(IconBase):
    class_name = "lucide lucide-a-large-small"
    svg_data = {
    "attrs": {
        "width": "24",
        "height": "24",
        "viewBox": "0 0 24 24",
        "fill": "none",
        "stroke": "currentColor",
        "stroke_width": "2",
        "stroke_linecap": "round",
        "stroke_linejoin": "round"
    },
    "items": [
        {
            "path": {
                "d": "M21 14h-5"
            }
        },
        {
            "path": {
                "d": "M16 16v-3.5a2.5 2.5 0 0 1 5 0V16"
            }
        },
        {
            "path": {
                "d": "M4.5 13h6"
            }
        },
        {
            "path": {
                "d": "m3 16 4.5-9 4.5 9"
            }
        }
    ]
}



from .. import IconBase


class IconDatabaseZap(IconBase):
    class_name = "lucide lucide-database-zap"
    svg_data = {
    "attrs": {
        "width": "24",
        "height": "24",
        "viewBox": "0 0 24 24",
        "fill": "none",
        "stroke": "currentColor",
        "stroke_width": "2",
        "stroke_linecap": "round",
        "stroke_linejoin": "round"
    },
    "items": [
        {
            "ellipse": {
                "cx": "12",
                "cy": "5",
                "rx": "9",
                "ry": "3"
            }
        },
        {
            "path": {
                "d": "M3 5V19A9 3 0 0 0 15 21.84"
            }
        },
        {
            "path": {
                "d": "M21 5V8"
            }
        },
        {
            "path": {
                "d": "M21 12L18 17H22L19 22"
            }
        },
        {
            "path": {
                "d": "M3 12A9 3 0 0 0 14.59 14.87"
            }
        }
    ]
}



from .. import IconBase


class IconMousePointerClick(IconBase):
    class_name = "lucide lucide-mouse-pointer-click"
    svg_data = {
    "attrs": {
        "width": "24",
        "height": "24",
        "viewBox": "0 0 24 24",
        "fill": "none",
        "stroke": "currentColor",
        "stroke_width": "2",
        "stroke_linecap": "round",
        "stroke_linejoin": "round"
    },
    "items": [
        {
            "path": {
                "d": "m9 9 5 12 1.8-5.2L21 14Z"
            }
        },
        {
            "path": {
                "d": "M7.2 2.2 8 5.1"
            }
        },
        {
            "path": {
                "d": "m5.1 8-2.9-.8"
            }
        },
        {
            "path": {
                "d": "M14 4.1 12 6"
            }
        },
        {
            "path": {
                "d": "m6 12-1.9 2"
            }
        }
    ]
}



from .. import IconBase


class IconPlugZap2(IconBase):
    class_name = "lucide lucide-plug-zap-2"
    svg_data = {
    "attrs": {
        "width": "24",
        "height": "24",
        "viewBox": "0 0 24 24",
        "fill": "none",
        "stroke": "currentColor",
        "stroke_width": "2",
        "stroke_linecap": "round",
        "stroke_linejoin": "round"
    },
    "items": [
        {
            "path": {
                "d": "m13 2-2 2.5h3L12 7"
            }
        },
        {
            "path": {
                "d": "M10 14v-3"
            }
        },
        {
            "path": {
                "d": "M14 14v-3"
            }
        },
        {
            "path": {
                "d": "M11 19c-1.7 0-3-1.3-3-3v-2h8v2c0 1.7-1.3 3-3 3Z"
            }
        },
        {
            "path": {
                "d": "M12 22v-3"
            }
        }
    ]
}



from .. import IconBase


class IconCoffee(IconBase):
    class_name = "lucide lucide-coffee"
    svg_data = {
    "attrs": {
        "width": "24",
        "height": "24",
        "viewBox": "0 0 24 24",
        "fill": "none",
        "stroke": "currentColor",
        "stroke_width": "2",
        "stroke_linecap": "round",
        "stroke_linejoin": "round"
    },
    "items": [
        {
            "path": {
                "d": "M10 2v2"
            }
        },
        {
            "path": {
                "d": "M14 2v2"
            }
        },
        {
            "path": {
                "d": "M16 8a1 1 0 0 1 1 1v8a4 4 0 0 1-4 4H7a4 4 0 0 1-4-4V9a1 1 0 0 1 1-1h14a4 4 0 1 1 0 8h-1"
            }
        },
        {
            "path": {
                "d": "M6 2v2"
            }
        }
    ]
}



from .. import IconBase


class IconMailMinus(IconBase):
    class_name = "lucide lucide-mail-minus"
    svg_data = {
    "attrs": {
        "width": "24",
        "height": "24",
        "viewBox": "0 0 24 24",
        "fill": "none",
        "stroke": "currentColor",
        "stroke_width": "2",
        "stroke_linecap": "round",
        "stroke_linejoin": "round"
    },
    "items": [
        {
            "path": {
                "d": "M22 15V6a2 2 0 0 0-2-2H4a2 2 0 0 0-2 2v12c0 1.1.9 2 2 2h8"
            }
        },
        {
            "path": {
                "d": "m22 7-8.97 5.7a1.94 1.94 0 0 1-2.06 0L2 7"
            }
        },
        {
            "path": {
                "d": "M16 19h6"
            }
        }
    ]
}



from .. import IconBase


class IconCloudDownload(IconBase):
    class_name = "lucide lucide-cloud-download"
    svg_data = {
    "attrs": {
        "width": "24",
        "height": "24",
        "viewBox": "0 0 24 24",
        "fill": "none",
        "stroke": "currentColor",
        "stroke_width": "2",
        "stroke_linecap": "round",
        "stroke_linejoin": "round"
    },
    "items": [
        {
            "path": {
                "d": "M4 14.899A7 7 0 1 1 15.71 8h1.79a4.5 4.5 0 0 1 2.5 8.242"
            }
        },
        {
            "path": {
                "d": "M12 12v9"
            }
        },
        {
            "path": {
                "d": "m8 17 4 4 4-4"
            }
        }
    ]
}



from .. import IconBase


class IconOctagonPause(IconBase):
    class_name = "lucide lucide-octagon-pause"
    svg_data = {
    "attrs": {
        "width": "24",
        "height": "24",
        "viewBox": "0 0 24 24",
        "fill": "none",
        "stroke": "currentColor",
        "stroke_width": "2",
        "stroke_linecap": "round",
        "stroke_linejoin": "round"
    },
    "items": [
        {
            "path": {
                "d": "M10 15V9"
            }
        },
        {
            "path": {
                "d": "M14 15V9"
            }
        },
        {
            "path": {
                "d": "M7.714 2h8.572L22 7.714v8.572L16.286 22H7.714L2 16.286V7.714z"
            }
        }
    ]
}



from .. import IconBase


class IconEraser(IconBase):
    class_name = "lucide lucide-eraser"
    svg_data = {
    "attrs": {
        "width": "24",
        "height": "24",
        "viewBox": "0 0 24 24",
        "fill": "none",
        "stroke": "currentColor",
        "stroke_width": "2",
        "stroke_linecap": "round",
        "stroke_linejoin": "round"
    },
    "items": [
        {
            "path": {
                "d": "m7 21-4.3-4.3c-1-1-1-2.5 0-3.4l9.6-9.6c1-1 2.5-1 3.4 0l5.6 5.6c1 1 1 2.5 0 3.4L13 21"
            }
        },
        {
            "path": {
                "d": "M22 21H7"
            }
        },
        {
            "path": {
                "d": "m5 11 9 9"
            }
        }
    ]
}



from .. import IconBase


class IconDumbbell(IconBase):
    class_name = "lucide lucide-dumbbell"
    svg_data = {
    "attrs": {
        "width": "24",
        "height": "24",
        "viewBox": "0 0 24 24",
        "fill": "none",
        "stroke": "currentColor",
        "stroke_width": "2",
        "stroke_linecap": "round",
        "stroke_linejoin": "round"
    },
    "items": [
        {
            "path": {
                "d": "m6.5 6.5 11 11"
            }
        },
        {
            "path": {
                "d": "m21 21-1-1"
            }
        },
        {
            "path": {
                "d": "m3 3 1 1"
            }
        },
        {
            "path": {
                "d": "m18 22 4-4"
            }
        },
        {
            "path": {
                "d": "m2 6 4-4"
            }
        },
        {
            "path": {
                "d": "m3 10 7-7"
            }
        },
        {
            "path": {
                "d": "m14 21 7-7"
            }
        }
    ]
}



from .. import IconBase


class IconShrub(IconBase):
    class_name = "lucide lucide-shrub"
    svg_data = {
    "attrs": {
        "width": "24",
        "height": "24",
        "viewBox": "0 0 24 24",
        "fill": "none",
        "stroke": "currentColor",
        "stroke_width": "2",
        "stroke_linecap": "round",
        "stroke_linejoin": "round"
    },
    "items": [
        {
            "path": {
                "d": "M12 22v-7l-2-2"
            }
        },
        {
            "path": {
                "d": "M17 8v.8A6 6 0 0 1 13.8 20v0H10v0A6.5 6.5 0 0 1 7 8h0a5 5 0 0 1 10 0Z"
            }
        },
        {
            "path": {
                "d": "m14 14-2 2"
            }
        }
    ]
}



from .. import IconBase


class IconPocket(IconBase):
    class_name = "lucide lucide-pocket"
    svg_data = {
    "attrs": {
        "width": "24",
        "height": "24",
        "viewBox": "0 0 24 24",
        "fill": "none",
        "stroke": "currentColor",
        "stroke_width": "2",
        "stroke_linecap": "round",
        "stroke_linejoin": "round"
    },
    "items": [
        {
            "path": {
                "d": "M4 3h16a2 2 0 0 1 2 2v6a10 10 0 0 1-10 10A10 10 0 0 1 2 11V5a2 2 0 0 1 2-2z"
            }
        },
        {
            "polyline": {
                "points": "8 10 12 14 16 10"
            }
        }
    ]
}



from .. import IconBase


class IconCone(IconBase):
    class_name = "lucide lucide-cone"
    svg_data = {
    "attrs": {
        "width": "24",
        "height": "24",
        "viewBox": "0 0 24 24",
        "fill": "none",
        "stroke": "currentColor",
        "stroke_width": "2",
        "stroke_linecap": "round",
        "stroke_linejoin": "round"
    },
    "items": [
        {
            "path": {
                "d": "m20.9 18.55-8-15.98a1 1 0 0 0-1.8 0l-8 15.98"
            }
        },
        {
            "ellipse": {
                "cx": "12",
                "cy": "19",
                "rx": "9",
                "ry": "3"
            }
        }
    ]
}



from .. import IconBase


class IconMic(IconBase):
    class_name = "lucide lucide-mic"
    svg_data = {
    "attrs": {
        "width": "24",
        "height": "24",
        "viewBox": "0 0 24 24",
        "fill": "none",
        "stroke": "currentColor",
        "stroke_width": "2",
        "stroke_linecap": "round",
        "stroke_linejoin": "round"
    },
    "items": [
        {
            "path": {
                "d": "M12 2a3 3 0 0 0-3 3v7a3 3 0 0 0 6 0V5a3 3 0 0 0-3-3Z"
            }
        },
        {
            "path": {
                "d": "M19 10v2a7 7 0 0 1-14 0v-2"
            }
        },
        {
            "line": {
                "x1": "12",
                "x2": "12",
                "y1": "19",
                "y2": "22"
            }
        }
    ]
}



from .. import IconBase


class IconGhost(IconBase):
    class_name = "lucide lucide-ghost"
    svg_data = {
    "attrs": {
        "width": "24",
        "height": "24",
        "viewBox": "0 0 24 24",
        "fill": "none",
        "stroke": "currentColor",
        "stroke_width": "2",
        "stroke_linecap": "round",
        "stroke_linejoin": "round"
    },
    "items": [
        {
            "path": {
                "d": "M9 10h.01"
            }
        },
        {
            "path": {
                "d": "M15 10h.01"
            }
        },
        {
            "path": {
                "d": "M12 2a8 8 0 0 0-8 8v12l3-3 2.5 2.5L12 19l2.5 2.5L17 19l3 3V10a8 8 0 0 0-8-8z"
            }
        }
    ]
}



from .. import IconBase


class IconGlassWater(IconBase):
    class_name = "lucide lucide-glass-water"
    svg_data = {
    "attrs": {
        "width": "24",
        "height": "24",
        "viewBox": "0 0 24 24",
        "fill": "none",
        "stroke": "currentColor",
        "stroke_width": "2",
        "stroke_linecap": "round",
        "stroke_linejoin": "round"
    },
    "items": [
        {
            "path": {
                "d": "M15.2 22H8.8a2 2 0 0 1-2-1.79L5 3h14l-1.81 17.21A2 2 0 0 1 15.2 22Z"
            }
        },
        {
            "path": {
                "d": "M6 12a5 5 0 0 1 6 0 5 5 0 0 0 6 0"
            }
        }
    ]
}



from .. import IconBase


class IconUtensils(IconBase):
    class_name = "lucide lucide-utensils"
    svg_data = {
    "attrs": {
        "width": "24",
        "height": "24",
        "viewBox": "0 0 24 24",
        "fill": "none",
        "stroke": "currentColor",
        "stroke_width": "2",
        "stroke_linecap": "round",
        "stroke_linejoin": "round"
    },
    "items": [
        {
            "path": {
                "d": "M3 2v7c0 1.1.9 2 2 2h4a2 2 0 0 0 2-2V2"
            }
        },
        {
            "path": {
                "d": "M7 2v20"
            }
        },
        {
            "path": {
                "d": "M21 15V2v0a5 5 0 0 0-5 5v6c0 1.1.9 2 2 2h3Zm0 0v7"
            }
        }
    ]
}



from .. import IconBase


class IconShoppingBag(IconBase):
    class_name = "lucide lucide-shopping-bag"
    svg_data = {
    "attrs": {
        "width": "24",
        "height": "24",
        "viewBox": "0 0 24 24",
        "fill": "none",
        "stroke": "currentColor",
        "stroke_width": "2",
        "stroke_linecap": "round",
        "stroke_linejoin": "round"
    },
    "items": [
        {
            "path": {
                "d": "M6 2 3 6v14a2 2 0 0 0 2 2h14a2 2 0 0 0 2-2V6l-3-4Z"
            }
        },
        {
            "path": {
                "d": "M3 6h18"
            }
        },
        {
            "path": {
                "d": "M16 10a4 4 0 0 1-8 0"
            }
        }
    ]
}



from .. import IconBase


class IconClipboardPaste(IconBase):
    class_name = "lucide lucide-clipboard-paste"
    svg_data = {
    "attrs": {
        "width": "24",
        "height": "24",
        "viewBox": "0 0 24 24",
        "fill": "none",
        "stroke": "currentColor",
        "stroke_width": "2",
        "stroke_linecap": "round",
        "stroke_linejoin": "round"
    },
    "items": [
        {
            "path": {
                "d": "M15 2H9a1 1 0 0 0-1 1v2c0 .6.4 1 1 1h6c.6 0 1-.4 1-1V3c0-.6-.4-1-1-1Z"
            }
        },
        {
            "path": {
                "d": "M8 4H6a2 2 0 0 0-2 2v14a2 2 0 0 0 2 2h12a2 2 0 0 0 2-2M16 4h2a2 2 0 0 1 2 2v2M11 14h10"
            }
        },
        {
            "path": {
                "d": "m17 10 4 4-4 4"
            }
        }
    ]
}



from .. import IconBase


class IconSignpostBig(IconBase):
    class_name = "lucide lucide-signpost-big"
    svg_data = {
    "attrs": {
        "width": "24",
        "height": "24",
        "viewBox": "0 0 24 24",
        "fill": "none",
        "stroke": "currentColor",
        "stroke_width": "2",
        "stroke_linecap": "round",
        "stroke_linejoin": "round"
    },
    "items": [
        {
            "path": {
                "d": "M10 9H4L2 7l2-2h6"
            }
        },
        {
            "path": {
                "d": "M14 5h6l2 2-2 2h-6"
            }
        },
        {
            "path": {
                "d": "M10 22V4a2 2 0 1 1 4 0v18"
            }
        },
        {
            "path": {
                "d": "M8 22h8"
            }
        }
    ]
}



from .. import IconBase


class IconConciergeBell(IconBase):
    class_name = "lucide lucide-concierge-bell"
    svg_data = {
    "attrs": {
        "width": "24",
        "height": "24",
        "viewBox": "0 0 24 24",
        "fill": "none",
        "stroke": "currentColor",
        "stroke_width": "2",
        "stroke_linecap": "round",
        "stroke_linejoin": "round"
    },
    "items": [
        {
            "path": {
                "d": "M3 20a1 1 0 0 1-1-1v-1a2 2 0 0 1 2-2h16a2 2 0 0 1 2 2v1a1 1 0 0 1-1 1Z"
            }
        },
        {
            "path": {
                "d": "M20 16a8 8 0 1 0-16 0"
            }
        },
        {
            "path": {
                "d": "M12 4v4"
            }
        },
        {
            "path": {
                "d": "M10 4h4"
            }
        }
    ]
}



from .. import IconBase


class IconPlug(IconBase):
    class_name = "lucide lucide-plug"
    svg_data = {
    "attrs": {
        "width": "24",
        "height": "24",
        "viewBox": "0 0 24 24",
        "fill": "none",
        "stroke": "currentColor",
        "stroke_width": "2",
        "stroke_linecap": "round",
        "stroke_linejoin": "round"
    },
    "items": [
        {
            "path": {
                "d": "M12 22v-5"
            }
        },
        {
            "path": {
                "d": "M9 8V2"
            }
        },
        {
            "path": {
                "d": "M15 8V2"
            }
        },
        {
            "path": {
                "d": "M18 8v5a4 4 0 0 1-4 4h-4a4 4 0 0 1-4-4V8Z"
            }
        }
    ]
}



from .. import IconBase


class IconShovel(IconBase):
    class_name = "lucide lucide-shovel"
    svg_data = {
    "attrs": {
        "width": "24",
        "height": "24",
        "viewBox": "0 0 24 24",
        "fill": "none",
        "stroke": "currentColor",
        "stroke_width": "2",
        "stroke_linecap": "round",
        "stroke_linejoin": "round"
    },
    "items": [
        {
            "path": {
                "d": "M2 22v-5l5-5 5 5-5 5z"
            }
        },
        {
            "path": {
                "d": "M9.5 14.5 16 8"
            }
        },
        {
            "path": {
                "d": "m17 2 5 5-.5.5a3.53 3.53 0 0 1-5 0s0 0 0 0a3.53 3.53 0 0 1 0-5L17 2"
            }
        }
    ]
}



from .. import IconBase


class IconFocus(IconBase):
    class_name = "lucide lucide-focus"
    svg_data = {
    "attrs": {
        "width": "24",
        "height": "24",
        "viewBox": "0 0 24 24",
        "fill": "none",
        "stroke": "currentColor",
        "stroke_width": "2",
        "stroke_linecap": "round",
        "stroke_linejoin": "round"
    },
    "items": [
        {
            "circle": {
                "cx": "12",
                "cy": "12",
                "r": "3"
            }
        },
        {
            "path": {
                "d": "M3 7V5a2 2 0 0 1 2-2h2"
            }
        },
        {
            "path": {
                "d": "M17 3h2a2 2 0 0 1 2 2v2"
            }
        },
        {
            "path": {
                "d": "M21 17v2a2 2 0 0 1-2 2h-2"
            }
        },
        {
            "path": {
                "d": "M7 21H5a2 2 0 0 1-2-2v-2"
            }
        }
    ]
}



from .. import IconBase


class IconPlay(IconBase):
    class_name = "lucide lucide-play"
    svg_data = {
    "attrs": {
        "width": "24",
        "height": "24",
        "viewBox": "0 0 24 24",
        "fill": "none",
        "stroke": "currentColor",
        "stroke_width": "2",
        "stroke_linecap": "round",
        "stroke_linejoin": "round"
    },
    "items": [
        {
            "polygon": {
                "points": "6 3 20 12 6 21 6 3"
            }
        }
    ]
}



from .. import IconBase


class IconFireExtinguisher(IconBase):
    class_name = "lucide lucide-fire-extinguisher"
    svg_data = {
    "attrs": {
        "width": "24",
        "height": "24",
        "viewBox": "0 0 24 24",
        "fill": "none",
        "stroke": "currentColor",
        "stroke_width": "2",
        "stroke_linecap": "round",
        "stroke_linejoin": "round"
    },
    "items": [
        {
            "path": {
                "d": "M15 6.5V3a1 1 0 0 0-1-1h-2a1 1 0 0 0-1 1v3.5"
            }
        },
        {
            "path": {
                "d": "M9 18h8"
            }
        },
        {
            "path": {
                "d": "M18 3h-3"
            }
        },
        {
            "path": {
                "d": "M11 3a6 6 0 0 0-6 6v11"
            }
        },
        {
            "path": {
                "d": "M5 13h4"
            }
        },
        {
            "path": {
                "d": "M17 10a4 4 0 0 0-8 0v10a2 2 0 0 0 2 2h4a2 2 0 0 0 2-2Z"
            }
        }
    ]
}



from .. import IconBase


class IconInbox(IconBase):
    class_name = "lucide lucide-inbox"
    svg_data = {
    "attrs": {
        "width": "24",
        "height": "24",
        "viewBox": "0 0 24 24",
        "fill": "none",
        "stroke": "currentColor",
        "stroke_width": "2",
        "stroke_linecap": "round",
        "stroke_linejoin": "round"
    },
    "items": [
        {
            "polyline": {
                "points": "22 12 16 12 14 15 10 15 8 12 2 12"
            }
        },
        {
            "path": {
                "d": "M5.45 5.11 2 12v6a2 2 0 0 0 2 2h16a2 2 0 0 0 2-2v-6l-3.45-6.89A2 2 0 0 0 16.76 4H7.24a2 2 0 0 0-1.79 1.11z"
            }
        }
    ]
}



from .. import IconBase


class IconBookOpen(IconBase):
    class_name = "lucide lucide-book-open"
    svg_data = {
    "attrs": {
        "width": "24",
        "height": "24",
        "viewBox": "0 0 24 24",
        "fill": "none",
        "stroke": "currentColor",
        "stroke_width": "2",
        "stroke_linecap": "round",
        "stroke_linejoin": "round"
    },
    "items": [
        {
            "path": {
                "d": "M2 3h6a4 4 0 0 1 4 4v14a3 3 0 0 0-3-3H2z"
            }
        },
        {
            "path": {
                "d": "M22 3h-6a4 4 0 0 0-4 4v14a3 3 0 0 1 3-3h7z"
            }
        }
    ]
}



from .. import IconBase


class IconUmbrellaOff(IconBase):
    class_name = "lucide lucide-umbrella-off"
    svg_data = {
    "attrs": {
        "width": "24",
        "height": "24",
        "viewBox": "0 0 24 24",
        "fill": "none",
        "stroke": "currentColor",
        "stroke_width": "2",
        "stroke_linecap": "round",
        "stroke_linejoin": "round"
    },
    "items": [
        {
            "path": {
                "d": "M12 2v1"
            }
        },
        {
            "path": {
                "d": "M15.5 21a1.85 1.85 0 0 1-3.5-1v-8H2a10 10 0 0 1 3.428-6.575"
            }
        },
        {
            "path": {
                "d": "M17.5 12H22A10 10 0 0 0 9.004 3.455"
            }
        },
        {
            "path": {
                "d": "m2 2 20 20"
            }
        }
    ]
}



from .. import IconBase


class IconWifi(IconBase):
    class_name = "lucide lucide-wifi"
    svg_data = {
    "attrs": {
        "width": "24",
        "height": "24",
        "viewBox": "0 0 24 24",
        "fill": "none",
        "stroke": "currentColor",
        "stroke_width": "2",
        "stroke_linecap": "round",
        "stroke_linejoin": "round"
    },
    "items": [
        {
            "path": {
                "d": "M12 20h.01"
            }
        },
        {
            "path": {
                "d": "M2 8.82a15 15 0 0 1 20 0"
            }
        },
        {
            "path": {
                "d": "M5 12.859a10 10 0 0 1 14 0"
            }
        },
        {
            "path": {
                "d": "M8.5 16.429a5 5 0 0 1 7 0"
            }
        }
    ]
}



from .. import IconBase


class IconWine(IconBase):
    class_name = "lucide lucide-wine"
    svg_data = {
    "attrs": {
        "width": "24",
        "height": "24",
        "viewBox": "0 0 24 24",
        "fill": "none",
        "stroke": "currentColor",
        "stroke_width": "2",
        "stroke_linecap": "round",
        "stroke_linejoin": "round"
    },
    "items": [
        {
            "path": {
                "d": "M8 22h8"
            }
        },
        {
            "path": {
                "d": "M7 10h10"
            }
        },
        {
            "path": {
                "d": "M12 15v7"
            }
        },
        {
            "path": {
                "d": "M12 15a5 5 0 0 0 5-5c0-2-.5-4-2-8H9c-1.5 4-2 6-2 8a5 5 0 0 0 5 5Z"
            }
        }
    ]
}



from .. import IconBase


class IconTable2(IconBase):
    class_name = "lucide lucide-table-2"
    svg_data = {
    "attrs": {
        "width": "24",
        "height": "24",
        "viewBox": "0 0 24 24",
        "fill": "none",
        "stroke": "currentColor",
        "stroke_width": "2",
        "stroke_linecap": "round",
        "stroke_linejoin": "round"
    },
    "items": [
        {
            "path": {
                "d": "M9 3H5a2 2 0 0 0-2 2v4m6-6h10a2 2 0 0 1 2 2v4M9 3v18m0 0h10a2 2 0 0 0 2-2V9M9 21H5a2 2 0 0 1-2-2V9m0 0h18"
            }
        }
    ]
}



from .. import IconBase


class IconDroplet(IconBase):
    class_name = "lucide lucide-droplet"
    svg_data = {
    "attrs": {
        "width": "24",
        "height": "24",
        "viewBox": "0 0 24 24",
        "fill": "none",
        "stroke": "currentColor",
        "stroke_width": "2",
        "stroke_linecap": "round",
        "stroke_linejoin": "round"
    },
    "items": [
        {
            "path": {
                "d": "M12 22a7 7 0 0 0 7-7c0-2-1-3.9-3-5.5s-3.5-4-4-6.5c-.5 2.5-2 4.9-4 6.5C6 11.1 5 13 5 15a7 7 0 0 0 7 7z"
            }
        }
    ]
}



from .. import IconBase


class IconMagnet(IconBase):
    class_name = "lucide lucide-magnet"
    svg_data = {
    "attrs": {
        "width": "24",
        "height": "24",
        "viewBox": "0 0 24 24",
        "fill": "none",
        "stroke": "currentColor",
        "stroke_width": "2",
        "stroke_linecap": "round",
        "stroke_linejoin": "round"
    },
    "items": [
        {
            "path": {
                "d": "m6 15-4-4 6.75-6.77a7.79 7.79 0 0 1 11 11L13 22l-4-4 6.39-6.36a2.14 2.14 0 0 0-3-3L6 15"
            }
        },
        {
            "path": {
                "d": "m5 8 4 4"
            }
        },
        {
            "path": {
                "d": "m12 15 4 4"
            }
        }
    ]
}



from .. import IconBase


class IconCoins(IconBase):
    class_name = "lucide lucide-coins"
    svg_data = {
    "attrs": {
        "width": "24",
        "height": "24",
        "viewBox": "0 0 24 24",
        "fill": "none",
        "stroke": "currentColor",
        "stroke_width": "2",
        "stroke_linecap": "round",
        "stroke_linejoin": "round"
    },
    "items": [
        {
            "circle": {
                "cx": "8",
                "cy": "8",
                "r": "6"
            }
        },
        {
            "path": {
                "d": "M18.09 10.37A6 6 0 1 1 10.34 18"
            }
        },
        {
            "path": {
                "d": "M7 6h1v4"
            }
        },
        {
            "path": {
                "d": "m16.71 13.88.7.71-2.82 2.82"
            }
        }
    ]
}



from .. import IconBase


class IconVegan(IconBase):
    class_name = "lucide lucide-vegan"
    svg_data = {
    "attrs": {
        "width": "24",
        "height": "24",
        "viewBox": "0 0 24 24",
        "fill": "none",
        "stroke": "currentColor",
        "stroke_width": "2",
        "stroke_linecap": "round",
        "stroke_linejoin": "round"
    },
    "items": [
        {
            "path": {
                "d": "M2 2a26.6 26.6 0 0 1 10 20c.9-6.82 1.5-9.5 4-14"
            }
        },
        {
            "path": {
                "d": "M16 8c4 0 6-2 6-6-4 0-6 2-6 6"
            }
        },
        {
            "path": {
                "d": "M17.41 3.6a10 10 0 1 0 3 3"
            }
        }
    ]
}



from .. import IconBase


class IconReceiptJapaneseYen(IconBase):
    class_name = "lucide lucide-receipt-japanese-yen"
    svg_data = {
    "attrs": {
        "width": "24",
        "height": "24",
        "viewBox": "0 0 24 24",
        "fill": "none",
        "stroke": "currentColor",
        "stroke_width": "2",
        "stroke_linecap": "round",
        "stroke_linejoin": "round"
    },
    "items": [
        {
            "path": {
                "d": "M4 2v20l2-1 2 1 2-1 2 1 2-1 2 1 2-1 2 1V2l-2 1-2-1-2 1-2-1-2 1-2-1-2 1Z"
            }
        },
        {
            "path": {
                "d": "m12 10 3-3"
            }
        },
        {
            "path": {
                "d": "m9 7 3 3v7.5"
            }
        },
        {
            "path": {
                "d": "M9 11h6"
            }
        },
        {
            "path": {
                "d": "M9 15h6"
            }
        }
    ]
}



from .. import IconBase


class IconTestTubeDiagonal(IconBase):
    class_name = "lucide lucide-test-tube-diagonal"
    svg_data = {
    "attrs": {
        "width": "24",
        "height": "24",
        "viewBox": "0 0 24 24",
        "fill": "none",
        "stroke": "currentColor",
        "stroke_width": "2",
        "stroke_linecap": "round",
        "stroke_linejoin": "round"
    },
    "items": [
        {
            "path": {
                "d": "M21 7 6.82 21.18a2.83 2.83 0 0 1-3.99-.01v0a2.83 2.83 0 0 1 0-4L17 3"
            }
        },
        {
            "path": {
                "d": "m16 2 6 6"
            }
        },
        {
            "path": {
                "d": "M12 16H4"
            }
        }
    ]
}



from .. import IconBase


class IconBell(IconBase):
    class_name = "lucide lucide-bell"
    svg_data = {
    "attrs": {
        "width": "24",
        "height": "24",
        "viewBox": "0 0 24 24",
        "fill": "none",
        "stroke": "currentColor",
        "stroke_width": "2",
        "stroke_linecap": "round",
        "stroke_linejoin": "round"
    },
    "items": [
        {
            "path": {
                "d": "M6 8a6 6 0 0 1 12 0c0 7 3 9 3 9H3s3-2 3-9"
            }
        },
        {
            "path": {
                "d": "M10.3 21a1.94 1.94 0 0 0 3.4 0"
            }
        }
    ]
}



from .. import IconBase


class IconFolders(IconBase):
    class_name = "lucide lucide-folders"
    svg_data = {
    "attrs": {
        "width": "24",
        "height": "24",
        "viewBox": "0 0 24 24",
        "fill": "none",
        "stroke": "currentColor",
        "stroke_width": "2",
        "stroke_linecap": "round",
        "stroke_linejoin": "round"
    },
    "items": [
        {
            "path": {
                "d": "M20 17a2 2 0 0 0 2-2V9a2 2 0 0 0-2-2h-3.9a2 2 0 0 1-1.69-.9l-.81-1.2a2 2 0 0 0-1.67-.9H8a2 2 0 0 0-2 2v9a2 2 0 0 0 2 2Z"
            }
        },
        {
            "path": {
                "d": "M2 8v11a2 2 0 0 0 2 2h14"
            }
        }
    ]
}



from .. import IconBase


class IconNavigationOff(IconBase):
    class_name = "lucide lucide-navigation-off"
    svg_data = {
    "attrs": {
        "width": "24",
        "height": "24",
        "viewBox": "0 0 24 24",
        "fill": "none",
        "stroke": "currentColor",
        "stroke_width": "2",
        "stroke_linecap": "round",
        "stroke_linejoin": "round"
    },
    "items": [
        {
            "path": {
                "d": "M8.43 8.43 3 11l8 2 2 8 2.57-5.43"
            }
        },
        {
            "path": {
                "d": "M17.39 11.73 22 2l-9.73 4.61"
            }
        },
        {
            "line": {
                "x1": "2",
                "x2": "22",
                "y1": "2",
                "y2": "22"
            }
        }
    ]
}



from .. import IconBase


class IconGavel(IconBase):
    class_name = "lucide lucide-gavel"
    svg_data = {
    "attrs": {
        "width": "24",
        "height": "24",
        "viewBox": "0 0 24 24",
        "fill": "none",
        "stroke": "currentColor",
        "stroke_width": "2",
        "stroke_linecap": "round",
        "stroke_linejoin": "round"
    },
    "items": [
        {
            "path": {
                "d": "m14.5 12.5-8 8a2.119 2.119 0 1 1-3-3l8-8"
            }
        },
        {
            "path": {
                "d": "m16 16 6-6"
            }
        },
        {
            "path": {
                "d": "m8 8 6-6"
            }
        },
        {
            "path": {
                "d": "m9 7 8 8"
            }
        },
        {
            "path": {
                "d": "m21 11-8-8"
            }
        }
    ]
}



from .. import IconBase


class IconFilePenLine(IconBase):
    class_name = "lucide lucide-file-pen-line"
    svg_data = {
    "attrs": {
        "width": "24",
        "height": "24",
        "viewBox": "0 0 24 24",
        "fill": "none",
        "stroke": "currentColor",
        "stroke_width": "2",
        "stroke_linecap": "round",
        "stroke_linejoin": "round"
    },
    "items": [
        {
            "path": {
                "d": "m18 5-3-3H6a2 2 0 0 0-2 2v16a2 2 0 0 0 2 2h12a2 2 0 0 0 2-2"
            }
        },
        {
            "path": {
                "d": "M8 18h1"
            }
        },
        {
            "path": {
                "d": "M18.4 9.6a2 2 0 1 1 3 3L17 17l-4 1 1-4Z"
            }
        }
    ]
}
